.. vicar documentation master file, created by
   sphinx-quickstart on Fri May 24 12:58:54 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ``vicar``'s documentation!
=====================================

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: forks/SETI/rms-vicar)

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   module


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
